"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const DEFAULT_TABLE_NAME = 'KeyValueCache';
const DEFAULT_PARTITION_KEY = 'CacheKey';
const DEFAULT_VALUE_ATTRIBUTE = 'CacheValue';
const DEFAULT_TTL_ATTRIBUTE = 'CacheTTL';
class DynamoDBCache {
    constructor(client, options = {}) {
        this.client = client;
        const { tableName = DEFAULT_TABLE_NAME, partitionKeyName = DEFAULT_PARTITION_KEY, valueAttribute = DEFAULT_VALUE_ATTRIBUTE, ttlAttribute = DEFAULT_TTL_ATTRIBUTE, } = options;
        this.tableName = tableName;
        this.partitionKeyName = partitionKeyName;
        this.valueAttribute = valueAttribute;
        this.ttlAttribute = ttlAttribute;
    }
    get(key) {
        const params = {
            Key: {
                [this.partitionKeyName]: key,
            },
            TableName: this.tableName,
        };
        return this.client
            .get(params)
            .promise()
            .then(({ Item = {} }) => Item[this.valueAttribute]);
    }
    set(key, value, options) {
        const params = {
            Item: {
                [this.partitionKeyName]: key,
                [this.valueAttribute]: value,
            },
            TableName: this.tableName,
        };
        if (options && options.ttl) {
            const expiresAt = new Date();
            expiresAt.setSeconds(expiresAt.getSeconds() + options.ttl);
            const epochSeconds = Math.floor(expiresAt.getTime() / 1000);
            params.Item[this.ttlAttribute] = epochSeconds;
        }
        return this.client
            .put(params)
            .promise()
            .then(() => { });
    }
    delete(key) {
        const params = {
            Key: {
                [this.partitionKeyName]: key,
            },
            TableName: this.tableName,
        };
        return this.client
            .delete(params)
            .promise()
            .then(() => { });
    }
}
exports.default = DynamoDBCache;
//# sourceMappingURL=index.js.map